@@ -1,12 +1,13 @@
+import urllib.parse
+import webbrowser
+from colorama import Fore
 import pandas as pd
 from typing import Literal, Optional
 
-from rapidata.rapidata_client.logging import logger
+from rapidata.rapidata_client.config import logger, managed_print, tracer
 from rapidata.rapidata_client.benchmark._detail_mapper import DetailMapper
 from rapidata.service.openapi_service import OpenAPIService
-from rapidata.api_client.models.update_leaderboard_response_config_model import (
-    UpdateLeaderboardResponseConfigModel,
-)
+from rapidata.api_client.models.update_leaderboard_model import UpdateLeaderboardModel
 
 
 class RapidataLeaderboard:
@@ -32,6 +33,7 @@ class RapidataLeaderboard:
         inverse_ranking: bool,
         response_budget: int,
         min_responses_per_matchup: int,
+        benchmark_id: str,
         id: str,
         openapi_service: OpenAPIService,
     ):
@@ -43,7 +45,9 @@ class RapidataLeaderboard:
         self.__inverse_ranking = inverse_ranking
         self.__response_budget = response_budget
         self.__min_responses_per_matchup = min_responses_per_matchup
+        self.__benchmark_id = benchmark_id
         self.id = id
+        self.__leaderboard_page = f"https://app.{self.__openapi_service.environment}/mri/benchmarks/{self.__benchmark_id}/leaderboard/{self.id}"
 
     @property
     def level_of_detail(self) -> Literal["low", "medium", "high", "very high"]:
@@ -59,15 +63,10 @@ class RapidataLeaderboard:
         """
         Sets the level of detail of the leaderboard.
         """
-        logger.debug(f"Setting level of detail to {level_of_detail}")
-        self.__openapi_service.leaderboard_api.leaderboard_leaderboard_id_response_config_put(
-            leaderboard_id=self.id,
-            update_leaderboard_response_config_model=UpdateLeaderboardResponseConfigModel(
-                responseBudget=DetailMapper.get_budget(level_of_detail),
-                minResponses=self.__min_responses_per_matchup,
-            ),
-        )
-        self.__response_budget = DetailMapper.get_budget(level_of_detail)
+        with tracer.start_as_current_span("RapidataLeaderboard.level_of_detail.setter"):
+            logger.debug(f"Setting level of detail to {level_of_detail}")
+            self.__response_budget = DetailMapper.get_budget(level_of_detail)
+            self._update_config()
 
     @property
     def min_responses_per_matchup(self) -> int:
@@ -81,23 +80,20 @@ class RapidataLeaderboard:
         """
         Sets the minimum number of responses required to be considered for the leaderboard.
         """
-        if not isinstance(min_responses, int):
-            raise ValueError("Min responses per matchup must be an integer")
+        with tracer.start_as_current_span(
+            "RapidataLeaderboard.min_responses_per_matchup.setter"
+        ):
+            if not isinstance(min_responses, int):
+                raise ValueError("Min responses per matchup must be an integer")
 
-        if min_responses < 3:
-            raise ValueError("Min responses per matchup must be at least 3")
+            if min_responses < 3:
+                raise ValueError("Min responses per matchup must be at least 3")
 
-        logger.debug(
-            f"Setting min responses per matchup to {min_responses} for leaderboard {self.name}"
-        )
-        self.__openapi_service.leaderboard_api.leaderboard_leaderboard_id_response_config_put(
-            leaderboard_id=self.id,
-            update_leaderboard_response_config_model=UpdateLeaderboardResponseConfigModel(
-                responseBudget=self.__response_budget,
-                minResponses=min_responses,
-            ),
-        )
-        self.__min_responses_per_matchup = min_responses
+            logger.debug(
+                f"Setting min responses per matchup to {min_responses} for leaderboard {self.name}"
+            )
+            self.__min_responses_per_matchup = min_responses
+            self._update_config()
 
     @property
     def show_prompt_asset(self) -> bool:
@@ -134,6 +130,20 @@ class RapidataLeaderboard:
         """
         return self.__name
 
+    @name.setter
+    def name(self, name: str):
+        """
+        Sets the name of the leaderboard.
+        """
+        with tracer.start_as_current_span("RapidataLeaderboard.name.setter"):
+            if not isinstance(name, str):
+                raise ValueError("Name must be a string")
+            if len(name) < 1:
+                raise ValueError("Name must be at least 1 character long")
+
+            self.__name = name
+            self._update_config()
+
     def get_standings(self, tags: Optional[list[str]] = None) -> pd.DataFrame:
         """
         Returns the standings of the leaderboard.
@@ -146,27 +156,59 @@ class RapidataLeaderboard:
         Returns:
             A pandas DataFrame containing the standings of the leaderboard.
         """
-
-        participants = self.__openapi_service.leaderboard_api.leaderboard_leaderboard_id_standings_get(
-            leaderboard_id=self.id, tags=tags
-        )
-
-        standings = []
-        for participant in participants.items:
-            standings.append(
-                {
-                    "name": participant.name,
-                    "wins": participant.wins,
-                    "total_matches": participant.total_matches,
-                    "score": (
-                        round(participant.score, 2)
-                        if participant.score is not None
-                        else None
-                    ),
-                }
+        with tracer.start_as_current_span("RapidataLeaderboard.get_standings"):
+            participants = self.__openapi_service.leaderboard_api.leaderboard_leaderboard_id_standings_get(
+                leaderboard_id=self.id, tags=tags
             )
 
-        return pd.DataFrame(standings)
+            standings = []
+            for participant in participants.items:
+                standings.append(
+                    {
+                        "name": participant.name,
+                        "wins": participant.wins,
+                        "total_matches": participant.total_matches,
+                        "score": (
+                            round(participant.score, 2)
+                            if participant.score is not None
+                            else None
+                        ),
+                    }
+                )
+
+            return pd.DataFrame(standings)
+
+    def view(self) -> None:
+        """
+        Views the leaderboard.
+        """
+        logger.info("Opening leaderboard page in browser...")
+        could_open_browser = webbrowser.open(self.__leaderboard_page)
+        if not could_open_browser:
+            encoded_url = urllib.parse.quote(
+                self.__leaderboard_page, safe="%/:=&?~#+!$,;'@()*[]"
+            )
+            managed_print(
+                Fore.RED
+                + f"Please open this URL in your browser: '{encoded_url}'"
+                + Fore.RESET
+            )
+
+    def _custom_config(self, response_budget: int, min_responses_per_matchup: int):
+        self.__response_budget = response_budget
+        self.__min_responses_per_matchup = min_responses_per_matchup
+        self._update_config()
+
+    def _update_config(self):
+        with tracer.start_as_current_span("RapidataLeaderboard._update_config"):
+            self.__openapi_service.leaderboard_api.leaderboard_leaderboard_id_patch(
+                leaderboard_id=self.id,
+                update_leaderboard_model=UpdateLeaderboardModel(
+                    name=self.__name,
+                    responseBudget=self.__response_budget,
+                    minResponses=self.__min_responses_per_matchup,
+                ),
+            )
 
     def __str__(self) -> str:
         return f"RapidataLeaderboard(name={self.name}, instruction={self.instruction}, show_prompt={self.show_prompt}, leaderboard_id={self.id})"
