@@ -2,7 +2,7 @@ import requests
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
 
-from rapidata.rapidata_client.config.config import rapidata_config
+from rapidata.rapidata_client.config.rapidata_config import rapidata_config
 
 
 class SessionManager:
@@ -18,8 +18,8 @@ class SessionManager:
             requests.Session: A singleton requests session with retry logic.
         """
         if cls._session is None:
-            max_retries: int = rapidata_config.upload_max_retries
-            max_workers: int = rapidata_config.max_upload_workers
+            max_retries: int = rapidata_config.upload.maxRetries
+            max_workers: int = rapidata_config.upload.maxWorkers
             cls._session = requests.Session()
             retries = Retry(
                 total=max_retries,
