@@ -1,6 +1,10 @@
 from rapidata.rapidata_client.selection._base_selection import RapidataSelection
-from rapidata.api_client.models.effort_capped_selection import EffortCappedSelection as EffortCappedSelectionModel
-from rapidata.rapidata_client.selection.retrieval_modes import RetrievalMode
+from rapidata.api_client.models.effort_capped_selection import (
+    EffortCappedSelection as EffortCappedSelectionModel,
+)
+from rapidata.rapidata_client.selection.rapidata_retrieval_modes import (
+    RapidataRetrievalMode,
+)
 
 
 class EffortSelection(RapidataSelection):
@@ -13,14 +17,21 @@ class EffortSelection(RapidataSelection):
         retrieval_mode (RetrievalMode): The retrieval mode for the task.
         max_iterations (int | None): The maximum number of iterations for the task.
     """
-    def __init__(self, effort_budget: int, retrieval_mode: RetrievalMode = RetrievalMode.Shuffled, max_iterations: int | None = None):
+
+    def __init__(
+        self,
+        effort_budget: int,
+        retrieval_mode: RapidataRetrievalMode = RapidataRetrievalMode.Shuffled,
+        max_iterations: int | None = None,
+    ):
         self.effort_budget = effort_budget
         self.retrieval_mode = retrieval_mode
         self.max_iterations = max_iterations
 
     def _to_model(self):
         return EffortCappedSelectionModel(
-            _t="EffortCappedSelection", 
-            effortBudget=self.effort_budget, 
-            retrievalMode=self.retrieval_mode.value, 
-            maxIterations=self.max_iterations)
+            _t="EffortCappedSelection",
+            effortBudget=self.effort_budget,
+            retrievalMode=self.retrieval_mode.value,
+            maxIterations=self.max_iterations,
+        )
