@@ -5,6 +5,7 @@ from rapidata.rapidata_client.settings import (
     NoShuffle,
     PlayVideoUntilTheEnd,
     AllowNeitherBoth,
+    SwapContextInstruction,
 )
 
 
@@ -21,6 +22,7 @@ class RapidataSettings:
         no_shuffle (NoShuffle): Only for classification and compare tasks. If true, the order of the categories / images will not be shuffled and presented in the same order as specified.
         play_video_until_the_end (PlayVideoUntilTheEnd): Allows users to only answer once the video has finished playing.
         allow_neither_both (AllowNeitherBoth): Only for compare tasks. If true, the users will be able to select neither or both instead of exclusively one of the options.
+        swap_context_instruction (SwapContextInstruction): Swap the place of the context and instruction.
 
     Example:
         ```python
@@ -37,3 +39,4 @@ class RapidataSettings:
     no_shuffle = NoShuffle
     play_video_until_the_end = PlayVideoUntilTheEnd
     allow_neither_both = AllowNeitherBoth
+    swap_context_instruction = SwapContextInstruction
