@@ -13,8 +13,8 @@ from rapidata.api_client.api.workflow_api import WorkflowApi
 from rapidata.api_client.api.participant_api import ParticipantApi
 from rapidata.api_client.configuration import Configuration
 from rapidata.service.credential_manager import CredentialManager
-from rapidata.rapidata_client.api.rapidata_exception import RapidataApiClient
-from rapidata.rapidata_client.logging import logger
+from rapidata.rapidata_client.api.rapidata_api_client import RapidataApiClient
+from rapidata.rapidata_client.config import logger
 
 
 class OpenAPIService:
@@ -127,7 +127,7 @@ class OpenAPIService:
     @property
     def benchmark_api(self) -> BenchmarkApi:
         return BenchmarkApi(self.api_client)
-    
+
     @property
     def participant_api(self) -> ParticipantApi:
         return ParticipantApi(self.api_client)
